echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[ ! -f /usr/share/ECM/cmake/ECMConfigVersion.cmake ] && echo "Installing extra_cmake_modules" && extension --install extra_cmake_modules && echo "Finished extra_cmake_modules"
# Recommended

if [ $BUILD_ALL == "false" ] && [[ $(cat /etc/extension/installed_version.list | grep plasma_wayland_protocols=1.18.0) == "" ]]; then
	echo "plasma_wayland_protocols" 					>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "plasma_wayland_protocols" 					>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
